log

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2025 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package log provides a standardized way to initialize github.com/rs/zerolog based loggers.

Index

Constants

This section is empty.

Variables

var Default zerolog.Logger

Default is the default global logger.

Functions

func New

func New(consoleWriter bool, out io.Writer) zerolog.Logger

New creates a New logger instance.

func SetLogLevel

func SetLogLevel(l string)

SetLogLevel sets the log level for all logger instances. NOTE: Can be called at any time to change the log level.

Types

This section is empty.

Jump to